EXPORTS
	??0CertWriter@@QAE@PAVOutput@@@Z @ 1 NONAME ; public: __thiscall CertWriter::CertWriter(class Output *)
	??1CCertUtils@@UAE@XZ @ 2 NONAME ; public: virtual __thiscall CCertUtils::~CCertUtils(void)
	?AddApplicationL@CCertUtils@@QBEXABVTDesC16@@VTUid@@@Z @ 3 NONAME ; public: void __thiscall CCertUtils::AddApplicationL(class TDesC16 const &,class TUid)const 
	?AddCACertsL@CCertUtils@@QAEXABVCDesC16Array@@0W4TCertificateFormat@@HABVTDesC16@@AAVCUnifiedCertStore@@AAVTRequestStatus@@@Z @ 4 NONAME ; public: void __thiscall CCertUtils::AddCACertsL(class CDesC16Array const &,class CDesC16Array const &,enum TCertificateFormat,int,class TDesC16 const &,class CUnifiedCertStore &,class TRequestStatus &)
	?AddCACertsL@CCertUtils@@QAEXABVCDesC16Array@@0W4TCertificateFormat@@HABVTDesC16@@AAVTRequestStatus@@@Z @ 5 NONAME ; public: void __thiscall CCertUtils::AddCACertsL(class CDesC16Array const &,class CDesC16Array const &,enum TCertificateFormat,int,class TDesC16 const &,class TRequestStatus &)
	?AddCert@CCertUtils@@QAEXABVTDesC16@@W4TCertificateFormat@@W4TCertificateOwnerType@@H00AAVCUnifiedCertStore@@AAVTRequestStatus@@@Z @ 6 NONAME ; public: void __thiscall CCertUtils::AddCert(class TDesC16 const &,enum TCertificateFormat,enum TCertificateOwnerType,int,class TDesC16 const &,class TDesC16 const &,class CUnifiedCertStore &,class TRequestStatus &)
	?AddCertL@CCertUtils@@QAEXABVTDesC16@@W4TCertificateFormat@@W4TCertificateOwnerType@@H00AAVTRequestStatus@@@Z @ 7 NONAME ; public: void __thiscall CCertUtils::AddCertL(class TDesC16 const &,enum TCertificateFormat,enum TCertificateOwnerType,int,class TDesC16 const &,class TDesC16 const &,class TRequestStatus &)
	?CertFromFileL@CCertUtils@@SAPAVCCertificate@@ABVTDesC16@@0AAVRFs@@W4TCertificateFormat@@@Z @ 8 NONAME ; public: static class CCertificate * __cdecl CCertUtils::CertFromFileL(class TDesC16 const &,class TDesC16 const &,class RFs &,enum TCertificateFormat)
	?CertFromFileLC@CCertUtils@@SAPAVCCertificate@@ABVTDesC16@@0AAVRFs@@W4TCertificateFormat@@@Z @ 9 NONAME ; public: static class CCertificate * __cdecl CCertUtils::CertFromFileLC(class TDesC16 const &,class TDesC16 const &,class RFs &,enum TCertificateFormat)
	?DiagnosticLC@CCertUtils@@QBEPAVHBufC16@@XZ @ 10 NONAME ; public: class HBufC16 * __thiscall CCertUtils::DiagnosticLC(void)const 
	?IsSelfSigned@CertWriter@@QAEHABVCX509Certificate@@@Z @ 11 NONAME ; public: int __thiscall CertWriter::IsSelfSigned(class CX509Certificate const &)
	?MapError@CCertUtils@@SA?AVTPtrC16@@W4TValidationError@@@Z @ 12 NONAME ; public: static class TPtrC16  __cdecl CCertUtils::MapError(enum TValidationError)
	?NewL@CCertUtils@@SAPAV1@AAVRFs@@@Z @ 13 NONAME ; public: static class CCertUtils * __cdecl CCertUtils::NewL(class RFs &)
	?NewLC@CCertUtils@@SAPAV1@AAVRFs@@@Z @ 14 NONAME ; public: static class CCertUtils * __cdecl CCertUtils::NewLC(class RFs &)
	?RemoveApplicationL@CCertUtils@@QBEXVTUid@@@Z @ 15 NONAME ; public: void __thiscall CCertUtils::RemoveApplicationL(class TUid)const 
	?RemoveCertsL@CCertUtils@@QAEXAAVCUnifiedCertStore@@AAVTRequestStatus@@@Z @ 16 NONAME ; public: void __thiscall CCertUtils::RemoveCertsL(class CUnifiedCertStore &,class TRequestStatus &)
	?RemoveCertsL@CCertUtils@@QAEXAAVTRequestStatus@@@Z @ 17 NONAME ; public: void __thiscall CCertUtils::RemoveCertsL(class TRequestStatus &)
	?SetOut@CertWriter@@QAEXPAVOutput@@@Z @ 18 NONAME ; public: void __thiscall CertWriter::SetOut(class Output *)
	?ShowAKI@CertWriter@@QAEXABVCX509Certificate@@@Z @ 19 NONAME ; public: void __thiscall CertWriter::ShowAKI(class CX509Certificate const &)
	?ShowAVA@CertWriter@@QAEXABVCX520AttributeTypeAndValue@@@Z @ 20 NONAME ; public: void __thiscall CertWriter::ShowAVA(class CX520AttributeTypeAndValue const &)
	?ShowAltName@CertWriter@@QAEXABVCX509CertExtension@@@Z @ 21 NONAME ; public: void __thiscall CertWriter::ShowAltName(class CX509CertExtension const &)
	?ShowBC@CertWriter@@QAEXABVCX509CertExtension@@@Z @ 22 NONAME ; public: void __thiscall CertWriter::ShowBC(class CX509CertExtension const &)
	?ShowCP@CertWriter@@QAEXABVCX509CertExtension@@@Z @ 23 NONAME ; public: void __thiscall CertWriter::ShowCP(class CX509CertExtension const &)
	?ShowDN@CertWriter@@QAEXABVCX500DistinguishedName@@@Z @ 24 NONAME ; public: void __thiscall CertWriter::ShowDN(class CX500DistinguishedName const &)
	?ShowEKU@CertWriter@@QAEXABVCX509CertExtension@@@Z @ 25 NONAME ; public: void __thiscall CertWriter::ShowEKU(class CX509CertExtension const &)
	?ShowExtensions@CertWriter@@QAEXABVCX509Certificate@@@Z @ 26 NONAME ; public: void __thiscall CertWriter::ShowExtensions(class CX509Certificate const &)
	?ShowFingerprint@CertWriter@@QAEXABVCX509Certificate@@@Z @ 27 NONAME ; public: void __thiscall CertWriter::ShowFingerprint(class CX509Certificate const &)
	?ShowGN@CertWriter@@QAEXABVCX509GeneralName@@@Z @ 28 NONAME ; public: void __thiscall CertWriter::ShowGN(class CX509GeneralName const &)
	?ShowKU@CertWriter@@QAEXABVCX509CertExtension@@@Z @ 29 NONAME ; public: void __thiscall CertWriter::ShowKU(class CX509CertExtension const &)
	?ShowNC@CertWriter@@QAEXABVCX509CertExtension@@@Z @ 30 NONAME ; public: void __thiscall CertWriter::ShowNC(class CX509CertExtension const &)
	?ShowPC@CertWriter@@QAEXABVCX509CertExtension@@@Z @ 31 NONAME ; public: void __thiscall CertWriter::ShowPC(class CX509CertExtension const &)
	?ShowPM@CertWriter@@QAEXABVCX509CertExtension@@@Z @ 32 NONAME ; public: void __thiscall CertWriter::ShowPM(class CX509CertExtension const &)
	?ShowPublicKey@CertWriter@@QAEXABVCX509Certificate@@@Z @ 33 NONAME ; public: void __thiscall CertWriter::ShowPublicKey(class CX509Certificate const &)
	?ShowSKI@CertWriter@@QAEXABVCX509Certificate@@@Z @ 34 NONAME ; public: void __thiscall CertWriter::ShowSKI(class CX509Certificate const &)
	?ShowSerialNumber@CertWriter@@QAEXABVTPtrC8@@@Z @ 35 NONAME ; public: void __thiscall CertWriter::ShowSerialNumber(class TPtrC8 const &)
	?ShowSignature@CertWriter@@QAEXABVCX509Certificate@@@Z @ 36 NONAME ; public: void __thiscall CertWriter::ShowSignature(class CX509Certificate const &)
	?ShowSigningAlgorithm@CertWriter@@QAEXABVCSigningAlgorithmIdentifier@@@Z @ 37 NONAME ; public: void __thiscall CertWriter::ShowSigningAlgorithm(class CSigningAlgorithmIdentifier const &)
	?ShowSubtrees@CertWriter@@QAEXABV?$CArrayPtrFlat@VCX509GeneralSubtree@@@@@Z @ 38 NONAME ; public: void __thiscall CertWriter::ShowSubtrees(class CArrayPtrFlat<class CX509GeneralSubtree> const &)
	?ShowValidityPeriod@CertWriter@@QAEXABVCX509Certificate@@@Z @ 39 NONAME ; public: void __thiscall CertWriter::ShowValidityPeriod(class CX509Certificate const &)
	?WriteCert@CertWriter@@QAEXABVCX509Certificate@@@Z @ 40 NONAME ; public: void __thiscall CertWriter::WriteCert(class CX509Certificate const &)
	?WriteError@CCertUtils@@SAXW4TValidationError@@AAVOutput@@@Z @ 41 NONAME ; public: static void __cdecl CCertUtils::WriteError(enum TValidationError,class Output &)

